]> sigrok.org Git - libsigrok.git/blobdiff - log.c
Don't define names ending with _t (POSIX reserved).
[libsigrok.git] / log.c
diff --git a/log.c b/log.c
index 47c37b88dda17e6c6b35086ac4113158a94ef693..44bd49c57dc9f5494397e4b7f1fb153e6c2f6e6d 100644 (file)
--- a/log.c
+++ b/log.c
@@ -48,13 +48,13 @@ static int sr_logv(void *cb_data, int loglevel, const char *format,
                   va_list args);
 
 /* Pointer to the currently selected log callback. Default: sr_logv(). */
-static sr_log_callback_t sr_log_callback = sr_logv;
+static sr_log_callback sr_log_cb = sr_logv;
 
 /*
  * Pointer to private data that can be passed to the log callback.
  * This can be used (for example) by C++ GUIs to pass a "this" pointer.
  */
-static void *sr_log_callback_data = NULL;
+static void *sr_log_cb_data = NULL;
 
 /* Log domain (a short string that is used as prefix for all messages). */
 /** @cond PRIVATE */
@@ -166,7 +166,7 @@ SR_API char *sr_log_logdomain_get(void)
  *
  * @since 0.1.0
  */
-SR_API int sr_log_callback_set(sr_log_callback_t cb, void *cb_data)
+SR_API int sr_log_callback_set(sr_log_callback cb, void *cb_data)
 {
        if (!cb) {
                sr_err("log: %s: cb was NULL", __func__);
@@ -175,8 +175,8 @@ SR_API int sr_log_callback_set(sr_log_callback_t cb, void *cb_data)
 
        /* Note: 'cb_data' is allowed to be NULL. */
 
-       sr_log_callback = cb;
-       sr_log_callback_data = cb_data;
+       sr_log_cb = cb;
+       sr_log_cb_data = cb_data;
 
        return SR_OK;
 }
@@ -184,7 +184,7 @@ SR_API int sr_log_callback_set(sr_log_callback_t cb, void *cb_data)
 /**
  * Set the libsigrok log callback to the default built-in one.
  *
* Additionally, the internal 'sr_log_callback_data' pointer is set to NULL.
  *
  * @return SR_OK upon success, a negative error code otherwise.
  *
@@ -196,8 +196,8 @@ SR_API int sr_log_callback_set_default(void)
         * Note: No log output in this function, as it should safely work
         * even if the currently set log callback is buggy/broken.
         */
-       sr_log_callback = sr_logv;
-       sr_log_callback_data = NULL;
+       sr_log_cb = sr_logv;
+       sr_log_cb_data = NULL;
 
        return SR_OK;
 }
@@ -228,7 +228,7 @@ SR_PRIV int sr_log(int loglevel, const char *format, ...)
        va_list args;
 
        va_start(args, format);
-       ret = sr_log_callback(sr_log_callback_data, loglevel, format, args);
+       ret = sr_log_cb(sr_log_cb_data, loglevel, format, args);
        va_end(args);
 
        return ret;
@@ -241,7 +241,7 @@ SR_PRIV int sr_spew(const char *format, ...)
        va_list args;
 
        va_start(args, format);
-       ret = sr_log_callback(sr_log_callback_data, SR_LOG_SPEW, format, args);
+       ret = sr_log_cb(sr_log_cb_data, SR_LOG_SPEW, format, args);
        va_end(args);
 
        return ret;
@@ -254,7 +254,7 @@ SR_PRIV int sr_dbg(const char *format, ...)
        va_list args;
 
        va_start(args, format);
-       ret = sr_log_callback(sr_log_callback_data, SR_LOG_DBG, format, args);
+       ret = sr_log_cb(sr_log_cb_data, SR_LOG_DBG, format, args);
        va_end(args);
 
        return ret;
@@ -267,7 +267,7 @@ SR_PRIV int sr_info(const char *format, ...)
        va_list args;
 
        va_start(args, format);
-       ret = sr_log_callback(sr_log_callback_data, SR_LOG_INFO, format, args);
+       ret = sr_log_cb(sr_log_cb_data, SR_LOG_INFO, format, args);
        va_end(args);
 
        return ret;
@@ -280,7 +280,7 @@ SR_PRIV int sr_warn(const char *format, ...)
        va_list args;
 
        va_start(args, format);
-       ret = sr_log_callback(sr_log_callback_data, SR_LOG_WARN, format, args);
+       ret = sr_log_cb(sr_log_cb_data, SR_LOG_WARN, format, args);
        va_end(args);
 
        return ret;
@@ -293,7 +293,7 @@ SR_PRIV int sr_err(const char *format, ...)
        va_list args;
 
        va_start(args, format);
-       ret = sr_log_callback(sr_log_callback_data, SR_LOG_ERR, format, args);
+       ret = sr_log_cb(sr_log_cb_data, SR_LOG_ERR, format, args);
        va_end(args);
 
        return ret;
@@ -184,7 +184,7 @@ SR_API int sr_log_callback_set(sr_log_callback_t cb, void *cb_data)
  * Set the libsigrok log callback to the default built-in one.
  *
- * Additionally, the internal 'sr_log_callback_data' pointer is set to NULL.
+ * Additionally, the internal 'sr_log_cb_data' pointer is set to NULL.
  *
  * @return SR_OK upon success, a negative error code otherwise.